==> nmeatoolkit-0.1.6.tar.gz: nmeatoolkit-0.1.6/nmeatoolkit/pipes/filter.py <==
# -*- coding: utf-8 -*-
# Copyright (C) 2021 Davide Gessa
'''
MIT License

Copyright (c) 2021 Davide Gessa

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
'''
import pynmea2
from .pipe import Pipe	

class FilterPipe(Pipe):
	"""  """
	def __init__(self, exclude = None, include = None):
		self.exclude = exclude
		self.include = include

	def transform(self, sentence: pynmea2.NMEASentence) -> list[pynmea2.NMEASentence]:
		s = sentence.sentence_type

		if self.exclude and s in self.exclude:
			return []
		if self.include and not (s in self.include):
			return []
		
		return [sentence]

==> nmeatoolkit-0.2.tar.gz: nmeatoolkit-0.2/nmeatoolkit/pipes/filter.py <==
# -*- coding: utf-8 -*-
# Copyright (C) 2021 - 2025 Davide Gessa
"""
MIT License

Copyright (c) 2021 - 2025 Davide Gessa

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""
from typing import List

import pynmea2

from .pipe import Pipe


class FilterPipe(Pipe):
    """ """

    def __init__(self, exclude=None, include=None):
        self.exclude = exclude
        self.include = include

    def transform(self, sentence: pynmea2.NMEASentence) -> List[pynmea2.NMEASentence]:
        s = sentence.sentence_type

        if self.exclude and s in self.exclude:
            return []
        if self.include and not (s in self.include):
            return []

        return [sentence]
